@@ -8,9 +8,10 @@ def dict_function(d, fn):
     signature = inspect.signature(fn)
 
     def key(*args, **kwargs):
-        arguments = signature.bind(*args, **kwargs).arguments
+        arguments = signature.bind(*args, **kwargs)
+        arguments.apply_defaults()
         result = {}
-        for k, v in arguments.items():
+        for k, v in arguments.arguments.items():
             if k in d:
                 if callable(d[k]):
                     v = d[k](v)
