@@ -14,10 +14,12 @@ class Lock:
 
     def _get_last_modified(self):
         self._check()
-        if not os.path.exists(self.time_path):
-            self.set_last_opened()
-        with open(self.time_path) as f:
-            return float(f.read())
+        try:
+            with open(self.time_path) as f:
+                return float(f.read())
+        except:
+            self.set_last_modified()
+            return self._get_last_modified()
 
     def opened_after_last_modification(self):
         self._check()
@@ -103,3 +105,6 @@ class LockedShelf:
 
     def __exit__(self, *args, **kwargs):
         self.lock.__exit__(*args, **kwargs)
+
+    def close(self):
+        self.shelf.close()
